@@ -12,10 +12,11 @@
 #include <QTest>
 #include <QtGlobal>
 
-#include "core/entryinternal.h"
-#include "core/installation.h"
-#include "core/itemsmodel.h"
-#include "core/questionmanager.h"
+#include "entry.h"
+#include "installation_p.h"
+#include "itemsmodel.h"
+#include "question.h"
+#include "questionmanager.h"
 
 using namespace KNSCore;
 
@@ -42,11 +43,12 @@ void InstallationTest::initTestCase()
 {
     // Just in case a previous test crashed
     cleanupTestCase();
-    qRegisterMetaType<EntryInternal>();
+    qRegisterMetaType<Entry>();
     QStandardPaths::setTestModeEnabled(true);
     installation = new Installation(this);
-    KConfigGroup grp = KSharedConfig::openConfig(dataDir + "installationtest.knsrc")->group("KNewStuff3");
-    QVERIFY(installation->readConfig(grp));
+    KConfigGroup grp = KSharedConfig::openConfig(dataDir + "installationtest.knsrc")->group("KNewStuff");
+    QString err;
+    QVERIFY(installation->readConfig(grp, err));
     connect(KNSCore::QuestionManager::instance(), &KNSCore::QuestionManager::askQuestion, this, [](KNSCore::Question *q) {
         q->setResponse(KNSCore::Question::YesResponse);
     });
@@ -72,24 +74,25 @@ void InstallationTest::testConfigFileReading()
 
 void InstallationTest::testInstallCommand()
 {
-    EntryInternal entry;
+    Entry entry;
     entry.setUniqueId("0");
+    entry.setName("testInstallCommand");
     entry.setPayload(QUrl::fromLocalFile(QFINDTESTDATA("data/testfile.txt")).toString());
     QSignalSpy spy(installation, &Installation::signalEntryChanged);
     installation->install(entry);
     QVERIFY(spy.wait());
-    QCOMPARE(entry.status(), KNS3::Entry::Installed);
+    QCOMPARE(entry.status(), KNSCore::Entry::Installed);
     QVERIFY(QFileInfo::exists("installed.txt"));
 }
 
 void InstallationTest::testUninstallCommand()
 {
-    EntryInternal entry;
+    Entry entry;
     entry.setUniqueId("0");
     QFile file("testFile.txt");
     file.open(QIODevice::WriteOnly);
     file.close();
-    entry.setStatus(KNS3::Entry::Installed);
+    entry.setStatus(KNSCore::Entry::Installed);
     entry.setInstalledFiles(QStringList(file.fileName()));
     QVERIFY(QFileInfo(file).exists());
     QVERIFY(!QFileInfo::exists("uninstalled.txt"));
@@ -97,7 +100,7 @@ void InstallationTest::testUninstallCommand()
     installation->uninstall(entry);
     QSignalSpy spy(installation, &Installation::signalEntryChanged);
     QVERIFY(spy.wait());
-    QCOMPARE(entry.status(), KNS3::Entry::Deleted);
+    QCOMPARE(entry.status(), KNSCore::Entry::Deleted);
     QVERIFY(!QFileInfo(file).exists());
     QVERIFY(QFileInfo::exists("uninstalled.txt"));
 }
@@ -109,10 +112,10 @@ void InstallationTest::testUninstallCommandDirectory()
     // This will be left over from the previous test, so clean it up first
     QFile::remove("uninstalled.txt");
 
-    EntryInternal entry;
+    Entry entry;
     entry.setUniqueId("0");
     QDir().mkdir(testDir);
-    entry.setStatus(KNS3::Entry::Installed);
+    entry.setStatus(KNSCore::Entry::Installed);
     entry.setInstalledFiles(QStringList(testDir));
     QVERIFY(QFileInfo::exists(testDir));
     QVERIFY(!QFileInfo::exists("uninstalled.txt"));
@@ -120,16 +123,16 @@ void InstallationTest::testUninstallCommandDirectory()
     installation->uninstall(entry);
     QSignalSpy spy(installation, &Installation::signalEntryChanged);
     QVERIFY(spy.wait());
-    QCOMPARE(entry.status(), KNS3::Entry::Deleted);
+    QCOMPARE(entry.status(), KNSCore::Entry::Deleted);
     QVERIFY(!QFileInfo::exists(testDir));
     QVERIFY(QFileInfo::exists("uninstalled.txt"));
 }
 
 void InstallationTest::testInstallCommandArchive()
 {
-    EntryInternal entry;
+    Entry entry;
     entry.setUniqueId("0");
-    entry.setStatus(KNS3::Entry::Downloadable);
+    entry.setStatus(KNSCore::Entry::Downloadable);
     entry.setPayload(QUrl::fromLocalFile(QFINDTESTDATA("data/archive_dir.tar.gz")).toString());
 
     installation->install(entry);
@@ -150,9 +153,9 @@ void InstallationTest::testInstallCommandArchive()
 
 void InstallationTest::testInstallCommandTopLevelFilesInArchive()
 {
-    EntryInternal entry;
+    Entry entry;
     entry.setUniqueId("0");
-    entry.setStatus(KNS3::Entry::Downloadable);
+    entry.setStatus(KNSCore::Entry::Downloadable);
     entry.setPayload(QUrl::fromLocalFile(QFINDTESTDATA("data/archive_toplevel_files.tar.gz")).toString());
 
     installation->install(entry);
@@ -176,7 +179,7 @@ void InstallationTest::testInstallCommandTopLevelFilesInArchive()
 
 void InstallationTest::testCopyError()
 {
-    EntryInternal entry;
+    Entry entry;
     entry.setUniqueId("0");
     entry.setPayload(QUrl::fromLocalFile(QStringLiteral("data/does_not_exist.txt")).toString());
     QSignalSpy spy(installation, &Installation::signalEntryChanged);
@@ -185,7 +188,7 @@ void InstallationTest::testCopyError()
     installation->install(entry);
     QVERIFY(errorSpy.wait());
     QCOMPARE(spy.count(), 0);
-    QCOMPARE(int(entry.status()), int(KNS3::Entry::Invalid));
+    QCOMPARE(int(entry.status()), int(KNSCore::Entry::Invalid));
 }
 
 QTEST_MAIN(InstallationTest)
