@@ -6,23 +6,26 @@
 
 #include "commentsmodel.h"
 
-#include "entryinternal.h"
+#include "entry.h"
 #include "knewstuffcore_debug.h"
 
 #include <KLocalizedString>
 
 #include <QTimer>
 
-namespace KNSCore {
-class CommentsModel::Private {
+namespace KNSCore
+{
+class CommentsModelPrivate
+{
 public:
-    Private(CommentsModel *qq)
+    CommentsModelPrivate(CommentsModel *qq)
         : q(qq)
-    {}
+    {
+    }
     CommentsModel *const q;
-    Engine *engine = nullptr;
+    EngineBase *engine = nullptr;
 
-    EntryInternal entry;
+    Entry entry;
 
     QList<std::shared_ptr<KNSCore::Comment>> comments;
 
@@ -31,17 +34,18 @@ public:
         ClearModel,
     };
     bool fetchThrottle = false;
-    void fetch(FetchOptions option = NoOption) {
+    void fetch(FetchOptions option = NoOption)
+    {
         if (fetchThrottle) {
             return;
         }
         fetchThrottle = true;
-        QTimer::singleShot(1, q, [this](){
+        QTimer::singleShot(1, q, [this]() {
             fetchThrottle = false;
         });
         // Sanity checks, because we need a few things to be correct before we can actually fetch comments...
         if (!engine) {
-            qCWarning(KNEWSTUFFCORE) << "CommentsModel must be parented on a KNSCore::Engine instance to be able to fetch comments";
+            qCWarning(KNEWSTUFFCORE) << "CommentsModel must be parented on a KNSCore::EngineBase instance to be able to fetch comments";
         }
         if (!entry.isValid()) {
             qCWarning(KNEWSTUFFCORE) << "Without an entry to fetch comments for, CommentsModel cannot fetch comments for it";
@@ -53,11 +57,11 @@ public:
                 q->beginResetModel();
                 comments.clear();
                 provider->disconnect(q);
-                q->connect(provider.data(), &Provider::commentsLoaded, q, [=](const QList<std::shared_ptr<KNSCore::Comment>> &newComments){
+                q->connect(provider.data(), &Provider::commentsLoaded, q, [=](const QList<std::shared_ptr<KNSCore::Comment>> &newComments) {
                     QList<std::shared_ptr<KNSCore::Comment>> actualNewComments;
                     for (const std::shared_ptr<KNSCore::Comment> &comment : newComments) {
                         bool commentIsKnown = false;
-                        for (const std::shared_ptr<KNSCore::Comment> &existingComment : qAsConst(comments)) {
+                        for (const std::shared_ptr<KNSCore::Comment> &existingComment : std::as_const(comments)) {
                             if (existingComment->id == comment->id) {
                                 commentIsKnown = true;
                                 break;
@@ -79,24 +83,22 @@ public:
             }
             int commentsPerPage = 100;
             int pageToLoad = comments.count() / commentsPerPage;
-            qCDebug(KNEWSTUFFCORE) << "Loading comments, page" << pageToLoad << "with current comment count" << comments.count() << "out of a total of" << entry.numberOfComments();
+            qCDebug(KNEWSTUFFCORE) << "Loading comments, page" << pageToLoad << "with current comment count" << comments.count() << "out of a total of"
+                                   << entry.numberOfComments();
             Q_EMIT provider->loadComments(entry, commentsPerPage, pageToLoad);
         }
     }
 };
 }
 
-KNSCore::CommentsModel::CommentsModel(Engine *parent)
+KNSCore::CommentsModel::CommentsModel(EngineBase *parent)
     : QAbstractListModel(parent)
-    , d(new Private(this))
+    , d(new CommentsModelPrivate(this))
 {
     d->engine = parent;
 }
 
-KNSCore::CommentsModel::~CommentsModel()
-{
-    delete d;
-}
+KNSCore::CommentsModel::~CommentsModel() = default;
 
 QHash<int, QByteArray> KNSCore::CommentsModel::roleNames() const
 {
@@ -109,100 +111,87 @@ QHash<int, QByteArray> KNSCore::CommentsModel::roleNames() const
         {DateRole, "date"},
         {ScoreRole, "score"},
         {ParentIndexRole, "parentIndex"},
-        {DepthRole, "depth"}
+        {DepthRole, "depth"},
     };
     return roles;
 }
 
 QVariant KNSCore::CommentsModel::data(const QModelIndex &index, int role) const
 {
-    QVariant value;
-    if (checkIndex(index)) {
-        std::shared_ptr<KNSCore::Comment> comment = d->comments[index.row()];
-        switch (role)
-        {
-            case IdRole:
-                value.setValue(comment->id);
-                break;
-            case SubjectRole:
-                value.setValue(comment->subject);
-                break;
-            case TextRole:
-                value.setValue(comment->text);
-                break;
-            case ChildCountRole:
-                value.setValue(comment->childCount);
-                break;
-            case UsernameRole:
-                value.setValue(comment->username);
-                break;
-            case DateRole:
-                value.setValue(comment->date);
-                break;
-            case ScoreRole:
-                value.setValue(comment->score);
-                break;
-            case ParentIndexRole:
-                {
-                    int idx{-1};
-                    if (comment->parent) {
-                        idx = d->comments.indexOf(comment->parent);
-                    }
-                    value.setValue(idx);
-                }
-                break;
-            case DepthRole:
-                {
-                    int depth{0};
-                    if (comment->parent) {
-                        std::shared_ptr<KNSCore::Comment> child = comment->parent;
-                        while (child) {
-                            ++depth;
-                            child = child->parent;
-                        }
-                    }
-                    value.setValue(depth);
-                }
-                break;
-            default:
-                value.setValue(i18nc("The value returned for an unknown role when requesting data from the model.", "Unknown CommentsModel role"));
-                break;
+    if (!checkIndex(index)) {
+        return QVariant();
+    }
+    const std::shared_ptr<KNSCore::Comment> comment = d->comments[index.row()];
+    switch (role) {
+    case IdRole:
+        return comment->id;
+    case SubjectRole:
+        return comment->subject;
+    case TextRole:
+        return comment->text;
+    case ChildCountRole:
+        return comment->childCount;
+    case UsernameRole:
+        return comment->username;
+    case DateRole:
+        return comment->date;
+    case ScoreRole:
+        return comment->score;
+    case ParentIndexRole:
+        return comment->parent ? d->comments.indexOf(comment->parent) : -1;
+    case DepthRole: {
+        int depth{0};
+        if (comment->parent) {
+            std::shared_ptr<KNSCore::Comment> child = comment->parent;
+            while (child) {
+                ++depth;
+                child = child->parent;
+            }
         }
+        return depth;
+    }
+    default:
+        return i18nc("The value returned for an unknown role when requesting data from the model.", "Unknown CommentsModel role");
     }
-    return value;
 }
 
 int KNSCore::CommentsModel::rowCount(const QModelIndex &parent) const
 {
-    if (parent.isValid())
+    if (parent.isValid()) {
         return 0;
+    }
     return d->comments.count();
 }
 
 bool KNSCore::CommentsModel::canFetchMore(const QModelIndex &parent) const
 {
-    if (parent.isValid())
+    if (parent.isValid()) {
         return false;
-    if (d->entry.numberOfComments() > d->comments.count())
+    }
+    if (d->entry.numberOfComments() > d->comments.count()) {
         return true;
+    }
     return false;
 }
 
 void KNSCore::CommentsModel::fetchMore(const QModelIndex &parent)
 {
-    if(parent.isValid())
+    if (parent.isValid()) {
         return;
+    }
     d->fetch();
 }
 
-const KNSCore::EntryInternal &KNSCore::CommentsModel::entry() const
+const KNSCore::Entry &KNSCore::CommentsModel::entry() const
 {
     return d->entry;
 }
 
-void KNSCore::CommentsModel::setEntry(const KNSCore::EntryInternal &newEntry)
+void KNSCore::CommentsModel::setEntry(const KNSCore::Entry &newEntry)
 {
     d->entry = newEntry;
-    d->fetch(Private::ClearModel);
+    d->fetch(CommentsModelPrivate::ClearModel);
     Q_EMIT entryChanged();
 }
+
+#include "moc_commentsmodel.cpp"
