@@ -18,7 +18,7 @@
 
 #include <memory>
 
-#include "entryinternal.h"
+#include "entry.h"
 #include "errorcode.h"
 
 #include "knewstuffcore_export.h"
@@ -26,6 +26,7 @@
 
 namespace KNSCore
 {
+class ProviderPrivate;
 struct Comment;
 /**
  * @short KNewStuff Base Provider class.
@@ -36,8 +37,6 @@ struct Comment;
  * static website providers.
  *
  * @author Jeremy Whiting <jpwhiting@kde.org>
- *
- * @internal
  */
 class KNEWSTUFFCORE_EXPORT Provider : public QObject
 {
@@ -93,6 +92,11 @@ public:
         }
 
         QString hashForRequest() const;
+        bool operator==(const SearchRequest &other) const
+        {
+            return sortMode == other.sortMode && filter == other.filter && searchTerm == other.searchTerm && categories == other.categories
+                && page == other.page && pageSize == other.pageSize;
+        }
     };
 
     /**
@@ -160,7 +164,7 @@ public:
 
     virtual bool isInitialized() const = 0;
 
-    virtual void setCachedEntries(const KNSCore::EntryInternal::List &cachedEntries) = 0;
+    virtual void setCachedEntries(const KNSCore::Entry::List &cachedEntries) = 0;
 
     /**
      * Retrieves the common name of the provider.
@@ -185,10 +189,10 @@ public:
      * Note: the engine connects to loadingFinished() signal to get the result
      */
     virtual void loadEntries(const KNSCore::Provider::SearchRequest &request) = 0;
-    virtual void loadEntryDetails(const KNSCore::EntryInternal &)
+    virtual void loadEntryDetails(const KNSCore::Entry &)
     {
     }
-    virtual void loadPayloadLink(const EntryInternal &entry, int linkId) = 0;
+    virtual void loadPayloadLink(const Entry &entry, int linkId) = 0;
     /**
      * Request a loading of comments from this provider. The engine listens to the
      * commentsLoaded() signal for the result
@@ -200,7 +204,7 @@ public:
      * @see commentsLoaded(const QList<shared_ptr<KNSCore::Comment>> comments)
      * @since 5.63
      */
-    Q_SIGNAL void loadComments(const EntryInternal &entry, int commentsPerPage, int page);
+    Q_SIGNAL void loadComments(const Entry &entry, int commentsPerPage, int page);
     /**
      * Request loading of the details for a specific person with the given username.
      * The engine listens to the personLoaded() for the result
@@ -290,19 +294,16 @@ public:
     {
         return false;
     }
-    virtual void vote(const EntryInternal &entry, uint rating)
+    virtual void vote(const Entry & /*entry*/, uint /*rating*/)
     {
-        Q_UNUSED(entry)
-        Q_UNUSED(rating)
     }
 
     virtual bool userCanBecomeFan()
     {
         return false;
     }
-    virtual void becomeFan(const EntryInternal &entry)
+    virtual void becomeFan(const Entry & /*entry*/)
     {
-        Q_UNUSED(entry)
     }
 
     /**
@@ -337,11 +338,11 @@ public:
 Q_SIGNALS:
     void providerInitialized(KNSCore::Provider *);
 
-    void loadingFinished(const KNSCore::Provider::SearchRequest &, const KNSCore::EntryInternal::List &) const;
-    void loadingFailed(const KNSCore::Provider::SearchRequest &);
+    void loadingFinished(const KNSCore::Provider::SearchRequest &, const KNSCore::Entry::List &) const;
+    void loadingFailed(const KNSCore::Provider::SearchRequest &) const;
 
-    void entryDetailsLoaded(const KNSCore::EntryInternal &);
-    void payloadLinkLoaded(const KNSCore::EntryInternal &);
+    void entryDetailsLoaded(const KNSCore::Entry &);
+    void payloadLinkLoaded(const KNSCore::Entry &);
     /**
      * Fired when new comments have been loaded
      * @param comments The list of newly loaded comments, in a depth-first order
@@ -369,15 +370,16 @@ Q_SIGNALS:
 
     void signalInformation(const QString &) const;
     void signalError(const QString &) const;
-    void signalErrorCode(const KNSCore::ErrorCode &errorCode, const QString &message, const QVariant &metadata) const;
+    void signalErrorCode(KNSCore::ErrorCode errorCode, const QString &message, const QVariant &metadata) const;
 
     void categoriesMetadataLoded(const QList<CategoryMetadata> &categories);
 
 protected:
-    QString mName;
-    QUrl mIcon;
+    void setName(const QString &name);
+    void setIcon(const QUrl &icon);
 
 private:
+    const std::unique_ptr<ProviderPrivate> d;
     Q_DISABLE_COPY(Provider)
 };
 
